@@ -63,6 +63,7 @@ struct _WnckWindowPrivate
   WnckClassGroup *class_group;
   Window group_leader;
   Window transient_for;
+  GdkRectangle icon_geometry;
   char *name;
   char *icon_name;
   char *session_id;
@@ -192,7 +193,7 @@ wnck_window_get_type (void)
 
   if (!object_type)
     {
-      static const GTypeInfo object_info =
+      const GTypeInfo object_info =
       {
         sizeof (WnckWindowClass),
         (GBaseInitFunc) NULL,
@@ -222,6 +223,7 @@ wnck_window_init (WnckWindow *window)
   window->priv->name = NULL;
   window->priv->icon_name = NULL;
   window->priv->workspace = ALL_WORKSPACES;
+  window->priv->icon_geometry.width = -1; /* invalid cached value */
 
   window->priv->icon_cache = _wnck_icon_cache_new ();
 }
@@ -549,7 +551,7 @@ wnck_window_get_application  (WnckWindow *window)
 WnckWindow*
 wnck_window_get_transient (WnckWindow *window)
 {
-  g_return_val_if_fail (WNCK_IS_WINDOW (window), None);
+  g_return_val_if_fail (WNCK_IS_WINDOW (window), NULL);
 
   return wnck_window_get (window->priv->transient_for);
 }
@@ -644,7 +646,7 @@ wnck_window_get_pid (WnckWindow *window)
  * @window: a #WnckWindow
  *
  * Gets the sort order of @window; used for ordering of the window in
- * the tasklist.  This is defined when the window is created.
+ * the tasklist.  The initial value is defined when the window is created.
  *
  * Return value: sort order of @window, or G_MAXINT if none available
  **/
@@ -656,6 +658,24 @@ wnck_window_get_sort_order (WnckWindow *window)
   return window->priv->sort_order;
 }
 
+/**
+ * wnck_window_set_sort_order:
+ * @window: a #WnckWindow
+ * @order: new order
+ *
+ * Sets the sort order of @window; used for ordering of the window in
+ * the tasklist. 
+ *
+ **/
+void        wnck_window_set_sort_order        (WnckWindow *window, 
+					       gint order)
+{ 
+  g_return_if_fail (WNCK_IS_WINDOW (window));
+  
+  window->priv->sort_order = order;
+  return;
+}
+
 /**
  * wnck_window_get_window_type:
  * @window: a #WnckWindow
@@ -1661,6 +1681,17 @@ wnck_window_set_icon_geometry (WnckWindow *window,
 			       int         width,
 			       int         height)
 {
+  if (window->priv->icon_geometry.x == x &&
+      window->priv->icon_geometry.y == y &&
+      window->priv->icon_geometry.width == width &&
+      window->priv->icon_geometry.height == height)
+    return;
+
+  window->priv->icon_geometry.x = x;
+  window->priv->icon_geometry.y = y;
+  window->priv->icon_geometry.width = width;
+  window->priv->icon_geometry.height = height;
+
   _wnck_set_icon_geometry (window->priv->xwindow,
                            x, y, width, height);
 }
@@ -2175,6 +2206,12 @@ update_actions (WnckWindow *window)
       else if (atoms[i] == _wnck_atom_get ("_NET_WM_ACTION_FULLSCREEN"))
         window->priv->actions |= WNCK_WINDOW_ACTION_FULLSCREEN;
 
+      else if (atoms[i] == _wnck_atom_get ("_NET_WM_ACTION_ABOVE"))
+        window->priv->actions |= WNCK_WINDOW_ACTION_ABOVE;
+
+      else if (atoms[i] == _wnck_atom_get ("_NET_WM_ACTION_BELOW"))
+        window->priv->actions |= WNCK_WINDOW_ACTION_BELOW;
+
       else
         {
           const char *name = _wnck_atom_name (atoms [i]);
